@@ -10,14 +10,14 @@
 #' @return This function returns a plot of the refcurve model.
 #' @export
 
-plot.refcurve <- function(x, newdata = data.frame(x = seq(0,1,0.01)), tau = seq(0.1,0.9,0.2),...){
-mean <- predict(x$modelo_m, newdata = newdata)
-sd <- sqrt(exp(predict(x$modelo_v, newdata = newdata)))
-epsilon <- quantile(x$res, probs = tau)
+plot.refcurve <- function(x, newdata = data.frame(x = seq(0, 1, 0.01)), tau = seq(0.1, 0.9, 0.2), ...) {
+  mean <- predict(x$modelo_m, newdata = newdata)
+  sd <- sqrt(exp(predict(x$modelo_v, newdata = newdata)))
+  epsilon <- quantile(x$res, probs = tau)
 
-cuants = matrix(0, ncol = length(epsilon), nrow = dim(newdata)[1])
-for(i in 1:length(epsilon))  cuants[,i] = mean + sd*epsilon[i]
+  cuants <- matrix(0, ncol = length(epsilon), nrow = dim(newdata)[1])
+  for (i in 1:length(epsilon)) cuants[, i] <- mean + sd * epsilon[i]
 
-plot(rev(x$modelo_m$model), col = "grey")
-invisible(apply(cuants, 2, function(x) lines(x ~ newdata[,1])))
+  plot(rev(x$modelo_m$model), col = "grey")
+  invisible(apply(cuants, 2, function(x) lines(x ~ newdata[, 1])))
 }
